#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 shell-escape
version:              0.2.0
visibility:           public
id:                   shell-escape-0.2.0-1nFNUOkhNba9Z5brVZ0J1L
key:                  shell-escape-0.2.0-1nFNUOkhNba9Z5brVZ0J1L
license:              BSD-3-Clause
maintainer:           oss@solidsnack.be
author:               Jason Dusek
homepage:             http://github.com/solidsnack/shell-escape
synopsis:             Shell escaping library.
description:
    Shell escaping library, offering both Bourne shell and Bash style escaping
    of ByteStrings.

category:             Text
abi:                  e79de7d981e9db8ffa9357cbc1abe8dc
exposed:              True
exposed-modules:      Data.ByteString.ShellEscape Text.ShellEscape
hidden-modules:
    Data.ByteString.ShellEscape.Escape
    Data.ByteString.ShellEscape.EscapeVector
    Data.ByteString.ShellEscape.Sh Data.ByteString.ShellEscape.Bash
    Data.ByteString.ShellEscape.Put

import-dirs:          /usr/lib/ghc-8.10.5/site-local/shell-escape-0.2.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/shell-escape-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/shell-escape-0.2.0
hs-libraries:         HSshell-escape-0.2.0-1nFNUOkhNba9Z5brVZ0J1L
depends:
    base-4.14.2.0 binary-0.8.8.0 bytestring-0.10.12.0
    containers-0.6.4.1 vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:
    /usr/share/doc/haskell-shell-escape/html/shell-escape.haddock

haddock-html:         /usr/share/doc/haskell-shell-escape/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

